package main

import (
	"html/template"
	"igar/storage"
	"io"
	"net/http"
	"strings"

	"github.com/google/uuid"
	"github.com/labstack/echo"
	//"github.com/labstack/echo/middleware"
)

type (
	TemplateRenderer struct {
		template *template.Template
	}
)

var (
	list *storage.EntryMap = &storage.EntryMap{
		Filename: "img/list.json",
	}
)

// FUNCTIONS

func genName() string {
	return strings.Replace(uuid.New().String(), "-", "", -1)
}

// TemplateRenderer

func (renderer *TemplateRenderer) Render(w io.Writer, name string, data interface{}, c echo.Context) error {
	return renderer.template.ExecuteTemplate(w, name, data)
}

func IndexController(c echo.Context) (err error) {
	entries, err := list.GetEntries()
	if err == nil {
		err = c.Render(http.StatusOK, "index.html", entries)
	}
	return
}

func ViewController(c echo.Context) (err error) {
	uuid := c.QueryParam("uuid")
	entry, err := list.GetEntry(uuid)
	if err == nil {
		err = c.Render(http.StatusOK, "view.html", entry)
	}
	if err != nil {
		c.Logger().Error(err)
	}
	return
}

func main() {
	e := echo.New()

	e.Renderer = &TemplateRenderer{
		template: template.Must(template.ParseGlob("templates/*.html")),
	}

	e.GET("/", IndexController)
	e.GET("/view", ViewController)

	//e.GET("/list", server.ListController)

	//e.GET("/rss", server.RSSController)
	//e.GET("/json", server.JSONController)
	//e.GET("/atom", server.AtomController)

	e.Static("/static", "static")
	e.Static("/img", "img")

	//admin := e.Group("/admin", middleware.BasicAuth(auth))

	//admin.GET("/", server.AdminController)
	//admin.POST("/post", server.PostController)
	//admin.DELETE("/post", DeleteController)

	//admin.Static("/static", "admin/static")

	e.Logger.Fatal(e.Start(":40404"))
}
